import VueI18Next from '@panter/vue-i18next'
import PageNotFound from 'ferda/common/PageNotFound.vue'
import i18next from 'i18next'
import Fetch from 'i18next-fetch-backend'
import LocalStorageBackend from 'i18next-localstorage-backend'
import Vue from 'vue'
import VueRouter from 'vue-router'
import Vuex, { Store as VuexStore } from 'vuex'
import YAML from 'yaml'

import { PluginStore } from './store'

const ferda_version_el = document.querySelector('#ferda-version')
export const ferda_version = ferda_version_el ? JSON.parse(ferda_version_el.textContent).version : 'no_version'

Vue.use(Vuex)
Vue.use(VueI18Next)
Vue.use(VueRouter)

// Setup default settings for router and extend them at module level
export const router = new VueRouter({ mode: 'history', routes: [{ path: '*', component: PageNotFound }] })

export const store = new VuexStore(PluginStore)

export const get_ferda_verification_i18next_options = () => ({
    lng: store.getters['preferences/selected_language'],
    fallbackLng: [store.getters['settings/LANGUAGE_CODE'], 'en'],
    ns: [
        'ferda_verification_common',
        'ferda_verification_contact',
        'ferda_verification_detail',
        'ferda_verification_domain',
        'ferda_verification_module',
        'common',
        'login',
        'notifications',
        'rule',
    ],
    defaultNS: 'ferda_verification_common',
    backend: {
        backends: [LocalStorageBackend, Fetch],
        backendOptions: [
            {
                versions: store.getters['settings/LANGUAGES'].reduce((language_versions, lang) => {
                    language_versions[lang[0]] = ferda_version
                    return language_versions
                }, {}),
            },
            {
                loadPath: '/static/ferda_verification/locales/{{lng}}/{{ns}}.yml',
                requestOptions: { cache: 'reload' },
                parse: data => YAML.parse(data),
            },
        ],
    },
})

export const i18n = new VueI18Next(i18next)
