"""Ferda verification plugin."""
from typing import Callable, cast

from django.urls import reverse_lazy
from django.utils.translation import gettext_lazy as _
from ferda.models import User
from ferda.plugins import PluginConfig, register

plugin_config = PluginConfig(  # pragma: no cover
    name=_("Verification"),
    url=reverse_lazy("ferda_verification:index"),
    icon="mdi-account-alert",
    access=cast(Callable[[User], bool], lambda user: user.has_perm("ferda_verification.can_view")),
    permissions=[
        ("ferda_verification.can_view", "Can view verification module"),
        ("ferda_verification.can_create", "Can create new verification"),
        ("ferda_verification.can_cancel", "Can cancel opened verification"),
        ("ferda_verification.can_approve_futile", "Can approve futile verifications"),
        ("ferda_verification.can_delay_status", "Can delay verification status"),
        ("ferda_verification.can_resend_message", "Can resend verification message"),
        (
            "ferda_verification.can_resolve_manual_check",
            "Can resolve manual check",
        ),
    ],
)

register("ferda_verification", plugin_config)
