const path = require('path')

const MiniCssExtractPlugin = require('mini-css-extract-plugin')
const { VueLoaderPlugin } = require('vue-loader')
const VuetifyLoaderPlugin = require('vuetify-loader/lib/plugin')

module.exports = {
    entry: {
        'js/main': [
            path.resolve(__dirname, 'assets/js/main.js'),
        ],
        'css/main': [
            path.resolve(__dirname, 'assets/scss/main.scss'),
        ],
    },
    output: {
        filename: '[name].js',
        path: path.resolve(__dirname, 'ferda_verification/static/ferda_verification'),
    },
    module: {
        rules: [{
            test: /\.js$/,
            include: path.join(__dirname, 'assets/js'),
            exclude: /node_modules/,
            use: ['babel-loader'],
        }, {
            test: /\.(s?c|sa)ss$/,
            oneOf: [{
                resourceQuery: /module/,
                use: [
                    MiniCssExtractPlugin.loader,
                    {
                        loader: 'css-loader',
                        options: {
                            modules: {
                                localIdentName: '[name]__[local]--[hash:base64:8]',
                                exportLocalsConvention: 'camelCase',
                            },
                        },
                    },
                    'postcss-loader',
                    'sass-loader',
                ],
            }, {
                use: [
                    MiniCssExtractPlugin.loader,
                    'css-loader',
                    'postcss-loader',
                    'sass-loader',
                ],
            }],
        }, {
            test: /\.styl$/,
            use: [
                MiniCssExtractPlugin.loader,
                'css-loader',
                'stylus-loader',
            ],
        }, {
            test: /\.vue$/,
            use: 'vue-loader',
        }, {
            test: /\.js$/,
            use: 'babel-loader',
            exclude: /node_modules/,
        }, {
            test: /\.(woff|woff2|ttf|eot|svg)(\?[\s\S]+)?$/,
            type: 'asset/resource',
            generator: {
                filename: 'webfonts/[name][ext]',
            },
        }],
    },
    plugins: [
        new VueLoaderPlugin(),
        new MiniCssExtractPlugin({
            filename: '[name].css',
            chunkFilename: '[id].css',
        }),
        new VuetifyLoaderPlugin(),
    ],
    resolve: {
        alias: {
            ferda: path.resolve(__dirname, 'node_modules/@cz-nic/fred-ferda/assets/js/components'),
            FerdaCSS: path.resolve(__dirname, 'node_modules/@cz-nic/fred-ferda/assets/scss'),
            FerdaJS: path.resolve(__dirname, 'node_modules/@cz-nic/fred-ferda/assets/js'),
            ferda_test: path.resolve(__dirname, 'node_modules/@cz-nic/fred-ferda/tests-js'),
            ferda_verification: path.resolve(__dirname, 'assets/js/components'),
            ferda_verification_css: path.resolve(__dirname, 'assets/scss'),
            ferda_verification_js: path.resolve(__dirname, 'assets/js'),
            ferda_verification_test: path.resolve(__dirname, 'tests-js'),

            // Prevent "$attrs and $listeners is readonly" error
            vue: require.resolve('vue/dist/vue.esm.js'),
        },
    },
}
